# frozen_string_literal: true

require_relative './helper'

module Cloudscreener
  # Allows to configure and search for cloud infrastructure
  class Api
    attr_accessor :fields
    attr_accessor :currency
    attr_accessor :dc
    attr_accessor :providers

    def initialize(email = nil, password = nil)
      @vms = []
      @email = email
      @password = password
      @fields = %i[name cpucs ram pnam dsiz dcnas]
      @currency = 'USD'
      @providers = []
      @dc = nil
    end

    def add_vm(vm)
      raise 'No VM given, please use add_vm(new VM(...))' unless vm

      @vms << vm

      self
    end

    def configure_credentials(email, password)
      @email = email
      @password = password
    end

    def vm_by_name(vm_name)
      @vms.find { |v| v.name == vm_name }
    end

    def search
      raise 'Credentials not set, please use configure_credentials().' unless @email && @password
      query = compute_query

      token = Helper.fetch_token(@email, @password)
      Helper.fetch_reco(token, query)
    end

    private

    def compute_query
      raise 'You must select at least one VM. Please use add_vm()' unless @vms.any?
      raise 'You must select at least one provider. Please use api.providers = %w[...]' unless @providers.any?

      {
        multi: @vms.map { |vm| vm.compute_query(@providers, @dc) },
        slice: @fields,
        currency: @currency
      }
    end
  end
end
