# frozen_string_literal: true

require 'uri'
require 'httparty'

module Cloudscreener
  # Cloudscreener api helper
  module Helper
    class << self
      def fetch_token(email, password)
        body = "email=#{URI.encode_www_form_component(email)}&password=#{URI.encode_www_form_component(password)}"

        response = post_raw('https://search.cloudscreener.com/token', body)

        raise response.message if response.code >= 400

        JSON.parse(response.body)['access_token']
      end

      def fetch_reco(token, query)
        response = post_json_with_token('https://api.cloudscreener.com/v1/reco', token, query.to_json)
        raise response.message if response.code >= 400

        JSON.parse(response.body)
      end

      private

      def post_raw(url, content)
        post_request(url, content, :'Content-Type' => 'application/x-www-form-urlencoded')
      end

      def post_json_with_token(url, token, content)
        post_request(url, content, :'Content-Type' => 'application/json', Authorization: "Bearer #{token}")
      end

      def post_request(url, content, headers)
        HTTParty.post(url, body: content, headers: headers)
      end
    end
  end
end
