# frozen_string_literal: true

module Cloudscreener
  # Represents a cloud virtual machine
  class VirtualMachine
    attr_accessor :name
    attr_accessor :cpus
    attr_accessor :ram
    attr_accessor :os
    attr_accessor :qty

    def initialize(name = nil)
      @name = name
      @cpus = nil
      @ram = nil
      @os = nil
      @qty = 1
    end

    def compute_query(providers, dc = nil)
      match = [{ field: 'pslg', op: 'in', value: providers }]
      near = []

      match << dc.compute_query if dc
      match << { field: 'os', value: @os } if @os

      %w[cpus ram].each do |field|
        value = instance_variable_get("@#{field}")

        near << { field: field, value: value } unless value.nil?
      end

      { match: match, near: near, qty: @qty }
    end
  end
end
